@@ -3,33 +3,7 @@
 #'@title This generates a class of symmetric rotatable response surface designs with neighbour effects under a polynomial model of order (s1-1)
 #'@examples
 #' library(rsdNE)
-#' sym(2,2,0.5)
-#' ##output:
-#' ## X matrix
-#'#      [,1] [,2] [,3]
-#'# [1,]    1   -1   -1
-#'# [2,]    1    1    1
-#'# [3,]    1    1   -1
-#'# [4,]    1   -1    1
-#'# [5,]    1   -1   -1
-#'# [6,]    1    1    1
-#'# [7,]    1   -1    1
-#'# [8,]    1    1   -1
-#'# [9,]    1   -1   -1
-#'#[10,]    1    1    1
-#'## Z prime Z matrix
-
-#'#     [,1] [,2] [,3]
-#'#[1,]   32    0    0
-#'#[2,]    0    4    0
-#'#[3,]    0    0    4
-#'## Z prime Z inverse matrix
-#'#     [,1]   [,2]   [,3]
-#'#[1,] 0.03125 0.00 0.00
-#'#[2,] 0.00000 0.25 0.00
-#'#[3,] 0.00000 0.00 0.25
-#'#[1] "total number of runs" "8"
-#'#[1] "variance of esitmated response" "0.5312"
+#' sym(2,2,0.3)
 #'@references Sarika et al.2009, Communications in Statistics-Theory and Methods; Sarika et al.2013, Ars Combinatoria
 #' @param s1 Number of levels of n1 factors, 1<s1<=6
 #' @param n1 Number of factors, 1<n1<=4
@@ -368,7 +342,7 @@ sym<-function(s1,n1,c){
   vec4<-c('variance of estimated response',unique(vec1) )
   #print(vec3)
   #print(vec4)
-printlist=list("X Matrix"= X, "Z_prime_Z matrix"=Z_prime_Z, "Inv(Z_prime_Z) matrix"=solve(Z_prime_Z),'Total number of runs'=max(vec2),'Variance of estimated response'=unique(vec1))
+printlist=list("X Matrix"= X, "Z_prime_Z matrix"=Z_prime_Z, "Inv(Z_prime_Z) matrix"=round(solve(Z_prime_Z),3),'Total number of runs'=max(vec2),'Variance of estimated response'=unique(vec1))
 return(printlist)
 }
 
@@ -395,30 +369,6 @@ return(printlist)
 #'@examples
 #'library(rsdNE)
 #' asym1(1,1,0.5)
-#' ##X matrix
-#'#      [,1] [,2] [,3] [,4]
-#'#[1,]    1   -1   -1    1
-#'#[2,]    1    1    1    1
-#'#[3,]    1    1    0    0
-#'#[4,]    1    1   -1    1
-#'#[5,]    1   -1    1    1
-#'#[6,]    1   -1    0    0
-#'#[7,]    1   -1   -1    1
-#'#[8,]    1    1    1    1
-#'##Z prime Z matrix
-#'#      [,1] [,2] [,3] [,4]
-#'#[1,]   24    0    0   16
-#'#[2,]    0   12    0    0
-#'#[3,]    0    0    1    0
-#'#[4,]   16    0    0   11
-#'##Z prime Z imverse matrix
-#'#      [,1]       [,2]   [,3]  [,4]
-#'#[1,]  1.375 0.00000000    0   -2
-#'#[2,]  0.000 0.08333333    0    0
-#'#[3,]  0.000 0.00000000    1    0
-#'#[4,] -2.000 0.00000000    0    3
-#'#[1] "total number of runs" "6"
-#'#[1] "variance of esitmated response" "1.4583"
 #'@references Verma et al.2021, Communication in Statistics – Simulation and Computation
 #' @description This function generates asymmetrical rotatable response surface designs in the presence of neighbour effects for 2n factors, n factors at 2 levels and another n factors at 3 levels.
 #' @param n1 n1 factors having 2 levels, 1<=n1<=5
@@ -687,7 +637,7 @@ asym1<-function(n1,n2,c){
   # print(vec3)
   # print(vec4)
 
-  printlist=list("X Matrix"= X, "Z_prime_Z matrix"=Z_prime_Z, "Inv(Z_prime_Z) matrix"=solve(Z_prime_Z),'Total number of runs'=max(vec2),'Variance of estimated response'=unique(vec1))
+  printlist=list("X Matrix"= X, "Z_prime_Z matrix"=Z_prime_Z, "Inv(Z_prime_Z) matrix"=round(solve(Z_prime_Z),3),'Total number of runs'=max(vec2),'Variance of estimated response'=unique(vec1))
   return(printlist)
 }
 
@@ -702,7 +652,7 @@ asym1<-function(n1,n2,c){
 #'@title This generates a class of asymmetric rotatable response surface designs with neighbour effects under a polynomial model of order max(s1,s2)-1
 #'@examples
 #'library(rsdNE)
-#'asym2(2,2,5,2,0.5)
+#'asym2(2,2,5,2,0.7)
 #'@references Dalal, 2021, Unpublished M.Sc. Thesis, IARI, New Delhi
 #' @description This function generates asymmetrical rotatable response surface designs in the presence of neighbour effects for (n1 + n2) factors, n1 factors at s1 levels and another n2 factors at s2 levels.
 #'@note  Here s1 and s2 both not even at the same time and s1 not equal to s2.
@@ -1045,7 +995,7 @@ asym2<-function(s1,n1,s2,n2,c){
   vec4<-c('variance of estimated response',unique(vec1))
   # print(vec3)
   # print(vec4)
-  printlist=list("X Matrix"= X, "Z_prime_Z matrix"=Z_prime_Z, "Inv(Z_prime_Z) matrix"=solve(Z_prime_Z),'Total number of runs'=max(vec2),'Variance of estimated response'=unique(vec1))
+  printlist=list("X Matrix"= X, "Z_prime_Z matrix"=Z_prime_Z, "Inv(Z_prime_Z) matrix"=round(solve(Z_prime_Z),3),'Total number of runs'=max(vec2),'Variance of estimated response'=unique(vec1))
   return(printlist)
 }
 
